===============================
Kingbird
===============================

Centralized service for multi-region OpenStack deployments.

Kingbird is an centralized OpenStack service that provides resource operation
and management across multiple OpenStack instances in a multi-region OpenStack
deployments. This service is part of the OPNFV Multisite project that intends
to address the use cases related to distributed cloud environments.

Kingbird provides features like centralized quota management, centralized view
for distributed virtual resources, global view for tenant level IP/MAC address
space management, synchronisation of ssh keys, images, flavors, security
groups, etc. across regions.


* Free software: Apache license
* Wiki:https://wiki.openstack.org/wiki/kingbird
* Documentation: http://docs.openstack.org/developer/kingbird
* Source: https://github.com/openstack/kingbird
* Bugs: http://bugs.launchpad.net/kingbird
* Blueprints: https://launchpad.net/kingbird

